@@ -49,5 +49,5 @@ class Domoticz(IPlugin):
 #				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
-			"body": bod
+#			"body": bod
 		}
